@@ -45,9 +45,11 @@ def main_concavity():
 		X = [float(default_param["X"])]
 		Y = [float(default_param["Y"])]
 	else:
-		X = [float(i) for i in default_param["X"]]
-		Y = [float(i) for i in default_param["Y"]]
-
+		try:
+			X = [float(i) for i in default_param["X"]]
+			Y = [float(i) for i in default_param["Y"]]
+		except:
+			pass
 
 	if(default_param["help"] or len(sys.argv)==1):
 		print("""
